==> docs_sdk_archive_luna-sdk_alma_rel_v.5.31.2.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.31.2/luna-sdk_alma_rel_v.5.31.2/doc/fsdk/html/structfsdk_1_1_i_face_engine_pos.js <==
var structfsdk_1_1_i_face_engine_pos =
[
    [ "createDescriptor", "group___core_group.html#gae20a1d4c999540c07dabf186d50f5dd8", null ],
    [ "createDescriptor", "group___core_group.html#ga913e7aa5858de2c39d83eba9313d4561", null ],
    [ "createDescriptorBatch", "group___core_group.html#ga0d5f3540428436318888c8f6715e76cf", null ],
    [ "createDetector", "group___core_group.html#gaaa6ad4311828697ee0eaf9584c295da9", null ],
    [ "createExtractor", "group___core_group.html#ga095b2b242fd6db0c2722f64ebdcd19e1", null ],
    [ "createGlassesEstimator", "group___core_group.html#gab9eb191eaaca532040358a98f7836fce", null ],
    [ "createHeadPoseEstimator", "group___core_group.html#ga9b3f7bec10940ac7d490abc1456111c3", null ],
    [ "createMatcher", "group___core_group.html#ga9adf17042977d9d7372d80de189bc771", null ],
    [ "createMedicalMaskEstimator", "group___core_group.html#ga68d05ea3a98add7dbdb0876cf72b5935", null ],
    [ "createNIRLivenessEstimator", "group___core_group.html#gaab53411e4c5a7cfcccf2746121d89383", null ],
    [ "createQualityEstimator", "group___core_group.html#ga87a0eab4f2694e53a2cc965f95dad380", null ],
    [ "createWarper", "group___core_group.html#ga9999055ce53a54e372cd6d3d4abb73ed", null ],
    [ "getDataDirectory", "group___core_group.html#gab0c365bbc9dcb3a01ffa0d75daefe2b1", null ],
    [ "getFaceEngineEdition", "group___core_group.html#ga66e12bdf7a9f0ad590cfe92a6c9592f7", null ],
    [ "getLicense", "group___core_group.html#ga6b1372e6e4798d05dc8a9ef051a848a4", null ],
    [ "getRuntimeSettingsProvider", "group___core_group.html#ga2a33e3dea9de884d0c8ac39b0d3420fb", null ],
    [ "getSettingsProvider", "group___core_group.html#ga96ba4e020e19bd764becdc6f4b1285e2", null ],
    [ "setDataDirectory", "group___core_group.html#ga3384924bf4b9d7287e7017b82d24af6e", null ],
    [ "setRuntimeSettingsProvider", "group___core_group.html#gab94cfa9a393ce00910e0619cceb560a9", null ],
    [ "setSettingsProvider", "group___core_group.html#ga46bd93c74b94d27d48a3d06849d4095c", null ]
];

==> docs_sdk_archive_luna-sdk_alma_rel_v.5.32.0.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.32.0/luna-sdk_alma_rel_v.5.32.0/doc/fsdk/html/structfsdk_1_1_i_face_engine_pos.js <==
var structfsdk_1_1_i_face_engine_pos =
[
    [ "createDescriptor", "group___core_group.html#gae20a1d4c999540c07dabf186d50f5dd8", null ],
    [ "createDescriptor", "group___core_group.html#ga913e7aa5858de2c39d83eba9313d4561", null ],
    [ "createDescriptorBatch", "group___core_group.html#ga0d5f3540428436318888c8f6715e76cf", null ],
    [ "createDetector", "group___core_group.html#gaaa6ad4311828697ee0eaf9584c295da9", null ],
    [ "createExtractor", "group___core_group.html#ga095b2b242fd6db0c2722f64ebdcd19e1", null ],
    [ "createGlassesEstimator", "group___core_group.html#gab9eb191eaaca532040358a98f7836fce", null ],
    [ "createHeadPoseEstimator", "group___core_group.html#ga9b3f7bec10940ac7d490abc1456111c3", null ],
    [ "createMatcher", "group___core_group.html#ga9adf17042977d9d7372d80de189bc771", null ],
    [ "createMedicalMaskEstimator", "group___core_group.html#ga68d05ea3a98add7dbdb0876cf72b5935", null ],
    [ "createQualityEstimator", "group___core_group.html#ga56a5951b05afb98952a5ddb0fd9ea8d7", null ],
    [ "createSubjectiveQualityEstimator", "group___core_group.html#ga61b50227465c79937812ab93ff9753f8", null ],
    [ "createWarper", "group___core_group.html#ga9999055ce53a54e372cd6d3d4abb73ed", null ],
    [ "FSDK_DEPRECATED", "group___core_group.html#ga5bd00c809dbfce9689147053f56ad9d2", null ],
    [ "getDataDirectory", "group___core_group.html#gab0c365bbc9dcb3a01ffa0d75daefe2b1", null ],
    [ "getFaceEngineEdition", "group___core_group.html#ga66e12bdf7a9f0ad590cfe92a6c9592f7", null ],
    [ "getLicense", "group___core_group.html#ga6b1372e6e4798d05dc8a9ef051a848a4", null ],
    [ "getRuntimeSettingsProvider", "group___core_group.html#ga2a33e3dea9de884d0c8ac39b0d3420fb", null ],
    [ "getSettingsProvider", "group___core_group.html#ga96ba4e020e19bd764becdc6f4b1285e2", null ],
    [ "setDataDirectory", "group___core_group.html#ga3384924bf4b9d7287e7017b82d24af6e", null ],
    [ "setRuntimeSettingsProvider", "group___core_group.html#gab94cfa9a393ce00910e0619cceb560a9", null ],
    [ "setSettingsProvider", "group___core_group.html#ga46bd93c74b94d27d48a3d06849d4095c", null ]
];
